@@ -1,29 +1,33 @@
-from typing import Optional, Union
-import asyncio
-import shutil
-import numpy as np
-import websockets
-import json
-import base64
-import os
 import abc
-import requests
-from openai import OpenAI
-from dotenv import load_dotenv
+import asyncio
+import base64
+import json
+import mimetypes
+import os
+import shutil
+import struct
+import subprocess
 from pathlib import Path
+from typing import Optional, Union
+
+import numpy as np
+import requests
+import requests.exceptions
+import soundfile as sf
+import websockets
+import websockets.exceptions
+from cartesia import Cartesia
+from dotenv import load_dotenv
+from google import genai
+from google.genai import types as genai_types
+from openai import OpenAI
 from tenacity import (
     retry,
+    retry_if_exception_type,
     stop_after_attempt,
     wait_exponential,
-    retry_if_exception_type,
 )
-import requests.exceptions
-import websockets.exceptions
 from websockets.exceptions import WebSocketException
-import subprocess
-import requests
-import soundfile as sf
-from cartesia import Cartesia  # Add this import at the top with other imports
 
 from .asr import create_asr_manager
 
@@ -190,7 +194,7 @@ class MiniMaxiTTSProvider(TTSProvider):
                 "voice_id": voice,
                 "speed": speed,
                 "vol": volume,
-                "pitch": pitch,
+                "pitch": int(pitch),  # MiniMaxi API expects pitch as integer
             },
             "audio_setting": {
                 "sample_rate": kwargs.get("sample_rate", 32000),
@@ -566,19 +570,191 @@ class OpenAIRealtimeTTSProvider(TTSProvider):
 
 class OpenAITTSProvider(TTSProvider):
     def __init__(self, api_key: str = None):
+        # OpenAI SDK now requires api_key as keyword-only argument
         self.client = OpenAI(api_key=api_key or os.getenv("OPENAI_API_KEY"))
+        self.available_voices = {
+            "alloy": {
+                "name": "alloy",
+                "description": "A female voice with a neutral, balanced tone, suitable for general-purpose applications.",
+                "labels": {
+                    "accent": "American",
+                    "description": "balanced and neutral",
+                    "age": "young adult",
+                    "gender": "female",
+                    "use_case": "general purpose",
+                },
+            },
+            "echo": {
+                "name": "echo",
+                "description": "A soft male voice with an androgynous quality, ideal for narration.",
+                "labels": {
+                    "accent": "American",
+                    "description": "soft and measured",
+                    "age": "adult",
+                    "gender": "male",
+                    "use_case": "narration",
+                },
+            },
+            "fable": {
+                "name": "fable",
+                "description": "A voice with a magical and dreamy tone, suitable for storytelling.",
+                "labels": {
+                    "accent": "American",
+                    "description": "magical and dreamy",
+                    "age": "indeterminate",
+                    "gender": "neutral",
+                    "use_case": "storytelling",
+                },
+            },
+            "onyx": {
+                "name": "onyx",
+                "description": "A deep, rich voice with a commanding presence.",
+                "labels": {
+                    "accent": "American",
+                    "description": "deep and commanding",
+                    "age": "adult",
+                    "gender": "male",
+                    "use_case": "authoritative narration",
+                },
+            },
+            "nova": {
+                "name": "nova",
+                "description": "A bright, energetic voice with a youthful quality.",
+                "labels": {
+                    "accent": "American",
+                    "description": "bright and energetic",
+                    "age": "young adult",
+                    "gender": "female",
+                    "use_case": "energetic content",
+                },
+            },
+            "shimmer": {
+                "name": "shimmer",
+                "description": "A female voice with a warm, welcoming tone perfect for casual content.",
+                "labels": {
+                    "accent": "American",
+                    "description": "warm and welcoming",
+                    "age": "young adult",
+                    "gender": "female",
+                    "use_case": "casual content",
+                },
+            },
+            "ash": {
+                "name": "ash",
+                "description": "A masculine voice with a clear, professional tone suitable for business content.",
+                "labels": {
+                    "accent": "American",
+                    "description": "clear and professional",
+                    "age": "adult",
+                    "gender": "male",
+                    "use_case": "business",
+                },
+            },
+            "coral": {
+                "name": "coral",
+                "description": "A female voice with an energetic, professional tone great for presentations.",
+                "labels": {
+                    "accent": "American",
+                    "description": "energetic and professional",
+                    "age": "adult",
+                    "gender": "female",
+                    "use_case": "presentations",
+                },
+            },
+            "sage": {
+                "name": "sage",
+                "description": "A female voice with a thoughtful, measured tone perfect for explanations.",
+                "labels": {
+                    "accent": "American",
+                    "description": "thoughtful and measured",
+                    "age": "adult",
+                    "gender": "female",
+                    "use_case": "explanations",
+                },
+            },
+            "ballad": {
+                "name": "ballad",
+                "description": "A male voice with a polished, commercial tone suited for marketing and announcements.",
+                "labels": {
+                    "accent": "American",
+                    "description": "polished and commercial",
+                    "age": "adult",
+                    "gender": "male",
+                    "use_case": "marketing",
+                },
+            },
+        }
+
+    def list_voices(self) -> list[dict]:
+        """Return list of available voices with their details"""
+        return [
+            {"name": k, "voice_id": k, **v} for k, v in self.available_voices.items()
+        ]
 
     def generate_speech(
         self,
         text: str,
         output_path: str,
         voice: str = "alloy",
-        model: str = "tts-1",
+        model: str = "gpt-4o-mini-tts",
+        instructions: str = None,
+        response_format: str = "mp3",
+        speed: float = 1.0,
         **kwargs,
     ) -> dict | None:
-        response = self.client.audio.speech.create(model=model, voice=voice, input=text)
-        response.stream_to_file(output_path)
-        return {"status": "success"}  # Return minimal dict for consistency
+        """
+        Generate speech using OpenAI's TTS API
+
+        Args:
+            text: The text to convert to speech
+            output_path: Where to save the resulting audio file
+            voice: One of the available voices (alloy, echo, fable, onyx, nova, shimmer, ash, coral, sage, ballad)
+            model: The TTS model to use (gpt-4o-mini-tts, tts-1, or tts-1-hd)
+            instructions: Optional instructions to guide the voice style (e.g., "Speak in a cheerful tone")
+            response_format: Output format (mp3, opus, aac, flac, wav, pcm)
+            speed: Speed of speech (0.5 to 2.0)
+            **kwargs: Additional parameters for future API options
+
+        Returns:
+            Dictionary with status and any additional information
+        """
+        # Validate parameters
+        if speed < 0.5 or speed > 2.0:
+            raise ValueError("Speed must be between 0.5 and 2.0")
+
+        # Create request parameters
+        request_params = {
+            "model": model,
+            "voice": voice,
+            "input": text,
+            "speed": speed,
+        }
+
+        # Add optional parameters if provided
+        if instructions:
+            request_params["instructions"] = instructions
+
+        if response_format:
+            request_params["response_format"] = response_format
+
+        # Generate audio
+        try:
+            response = self.client.audio.speech.create(**request_params)
+            response.stream_to_file(output_path)
+
+            return {
+                "status": "success",
+                "model": model,
+                "voice": voice,
+                "output_format": response_format,
+            }
+
+        except Exception as e:
+            # Handle rate limit errors specifically
+            if "rate limit" in str(e).lower():
+                raise TTSRateLimitError(f"OpenAI API rate limit exceeded: {str(e)}")
+            # Handle other errors
+            raise TTSError(f"OpenAI TTS generation failed: {str(e)}")
 
 
 class ElevenLabsTTSProvider(TTSProvider):
@@ -945,7 +1121,7 @@ class CartesiaTTSProvider(TTSProvider):
         text: str,
         output_path: str,
         voice: str,
-        model_id: str = "sonic",
+        model_id: str = "sonic-2",
         language: str = "en",
         **kwargs,
     ) -> dict | None:
@@ -966,7 +1142,7 @@ class CartesiaTTSProvider(TTSProvider):
                 output_format["bit_rate"] = kwargs.get("bit_rate", 128000)
 
             # Generate audio using the SDK
-            response = self.client.tts.bytes(
+            response_generator = self.client.tts.bytes(
                 model_id=model_id,
                 transcript=text,
                 voice=voice_spec,
@@ -974,9 +1150,17 @@ class CartesiaTTSProvider(TTSProvider):
                 output_format=output_format,
             )
 
+            # Collect all audio chunks from the generator
+            audio_chunks = []
+            for chunk in response_generator:
+                audio_chunks.append(chunk)
+
+            # Combine all chunks into a single bytes object
+            audio_data = b"".join(audio_chunks)
+
             # Save the audio response
             with open(output_path, "wb") as f:
-                f.write(response)
+                f.write(audio_data)
 
             result = {"status": "success"}
 
@@ -989,7 +1173,7 @@ class CartesiaTTSProvider(TTSProvider):
 
                 try:
                     with open(temp_file, "wb") as f:
-                        f.write(response)
+                        f.write(audio_data)
                     asr_result = self.asr_manager.transcribe(
                         "openai", temp_file, language=language
                     )
@@ -1052,6 +1236,563 @@ class CartesiaTTSProvider(TTSProvider):
                 raise TTSRateLimitError(f"Cartesia API rate limit exceeded: {str(e)}")
             raise TTSError(f"Cartesia voice conversion failed: {str(e)}")
 
+    def print_available_voices(self):
+        """Debug helper to print available voices"""
+        try:
+            voices = self.client.voices.list()
+            print("Available voices:")
+            for voice in voices:
+                print(
+                    f"  - {voice.get('name', 'Unknown')} (ID: {voice.get('id', 'Unknown')})"
+                )
+                print(f"    Language: {voice.get('language', 'Unknown')}")
+                print(f"    Description: {voice.get('description', 'None')}")
+                print("")
+        except Exception as e:
+            print(f"Error listing voices: {e}")
+
+
+class GeminiTTSProvider(TTSProvider):
+    def __init__(self, api_key: str = None):
+        self.api_key = api_key or os.getenv("GEMINI_API_KEY")
+        self.client = genai.Client(api_key=self.api_key)
+        self.asr_manager = create_asr_manager()
+        self.available_voices = {
+            "Zephyr": {
+                "name": "Zephyr",
+                "description": "Bright, cheerful tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "bright",
+                    "use_case": "general purpose",
+                },
+            },
+            "Puck": {
+                "name": "Puck",
+                "description": "Upbeat, energetic delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "upbeat",
+                    "use_case": "energetic content",
+                },
+            },
+            "Charon": {
+                "name": "Charon",
+                "description": "Informative, clear tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "informative",
+                    "use_case": "educational content",
+                },
+            },
+            "Kore": {
+                "name": "Kore",
+                "description": "Firm, authoritative tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "firm",
+                    "use_case": "business",
+                },
+            },
+            "Fenrir": {
+                "name": "Fenrir",
+                "description": "Excitable, animated delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "excitable",
+                    "use_case": "entertainment",
+                },
+            },
+            "Leda": {
+                "name": "Leda",
+                "description": "Youthful, fresh tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "youthful",
+                    "use_case": "young audience",
+                },
+            },
+            "Orus": {
+                "name": "Orus",
+                "description": "Firm, steady delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "firm",
+                    "use_case": "authoritative content",
+                },
+            },
+            "Aoede": {
+                "name": "Aoede",
+                "description": "Breezy, light tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "breezy",
+                    "use_case": "casual content",
+                },
+            },
+            "Callirhoe": {
+                "name": "Callirhoe",
+                "description": "Easy-going, relaxed tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "easy-going",
+                    "use_case": "conversational",
+                },
+            },
+            "Autonoe": {
+                "name": "Autonoe",
+                "description": "Bright, cheerful delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "bright",
+                    "use_case": "positive content",
+                },
+            },
+            "Enceladus": {
+                "name": "Enceladus",
+                "description": "Breathy, soft tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "breathy",
+                    "use_case": "intimate content",
+                },
+            },
+            "Iapetus": {
+                "name": "Iapetus",
+                "description": "Clear, articulate delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "clear",
+                    "use_case": "professional",
+                },
+            },
+            "Umbriel": {
+                "name": "Umbriel",
+                "description": "Easy-going, casual tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "easy-going",
+                    "use_case": "friendly content",
+                },
+            },
+            "Algieba": {
+                "name": "Algieba",
+                "description": "Smooth tone (note: may have compatibility issues)",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "unknown",
+                    "characteristic": "smooth",
+                    "use_case": "general purpose",
+                    "note": "potentially buggy",
+                },
+            },
+            "Despina": {
+                "name": "Despina",
+                "description": "Smooth, pleasant delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "smooth",
+                    "use_case": "narration",
+                },
+            },
+            "Erinome": {
+                "name": "Erinome",
+                "description": "Clear, crisp tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "clear",
+                    "use_case": "instructional",
+                },
+            },
+            "Algenib": {
+                "name": "Algenib",
+                "description": "Gravelly, textured delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "gravelly",
+                    "use_case": "dramatic content",
+                },
+            },
+            "Rasalgethi": {
+                "name": "Rasalgethi",
+                "description": "Informative, educational tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "informative",
+                    "use_case": "educational",
+                },
+            },
+            "Laomedeia": {
+                "name": "Laomedeia",
+                "description": "Upbeat, lively delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "upbeat",
+                    "use_case": "motivational",
+                },
+            },
+            "Achernar": {
+                "name": "Achernar",
+                "description": "Soft, gentle tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "soft",
+                    "use_case": "calming content",
+                },
+            },
+            "Alnilam": {
+                "name": "Alnilam",
+                "description": "Firm, confident delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "firm",
+                    "use_case": "authoritative",
+                },
+            },
+            "Schedar": {
+                "name": "Schedar",
+                "description": "Even, balanced tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "even",
+                    "use_case": "neutral narration",
+                },
+            },
+            "Gacrux": {
+                "name": "Gacrux",
+                "description": "Mature, sophisticated delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "mature",
+                    "use_case": "professional",
+                },
+            },
+            "Pulcherrima": {
+                "name": "Pulcherrima",
+                "description": "Forward, assertive tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "forward",
+                    "use_case": "confident content",
+                },
+            },
+            "Achird": {
+                "name": "Achird",
+                "description": "Friendly, approachable delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "friendly",
+                    "use_case": "conversational",
+                },
+            },
+            "Zubenelgenubi": {
+                "name": "Zubenelgenubi",
+                "description": "Casual, relaxed tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "casual",
+                    "use_case": "informal content",
+                },
+            },
+            "Vindemiatrix": {
+                "name": "Vindemiatrix",
+                "description": "Gentle, soothing delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "gentle",
+                    "use_case": "therapeutic content",
+                },
+            },
+            "Sadachbia": {
+                "name": "Sadachbia",
+                "description": "Lively, energetic tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "lively",
+                    "use_case": "entertainment",
+                },
+            },
+            "Sadaltager": {
+                "name": "Sadaltager",
+                "description": "Knowledgeable, wise delivery",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "male",
+                    "characteristic": "knowledgeable",
+                    "use_case": "educational",
+                },
+            },
+            "Sulafat": {
+                "name": "Sulafat",
+                "description": "Warm, welcoming tone",
+                "labels": {
+                    "provider": "Gemini",
+                    "model": "gemini-2.5-pro-preview-tts",
+                    "gender": "female",
+                    "characteristic": "warm",
+                    "use_case": "hospitality content",
+                },
+            },
+        }
+
+    def list_voices(self) -> list[dict]:
+        """Return list of available voices with their details"""
+        return [
+            {"name": k, "voice_id": k, **v} for k, v in self.available_voices.items()
+        ]
+
+    def generate_speech(
+        self,
+        text: str,
+        output_path: str,
+        voice: str = "Charon",
+        model: str = "gemini-2.5-pro-preview-tts",
+        temperature: float = 1.0,
+        instructions: str = None,
+        **kwargs,
+    ) -> dict | None:
+        """Generate speech using Google Gemini's TTS API
+
+        Args:
+            text: The text to convert to speech
+            output_path: Where to save the resulting audio file
+            voice: One of the available prebuilt voices (Charon, Milagros, Jaemin, etc.)
+            model: The TTS model to use (gemini-2.5-pro-preview-tts or gemini-2.5-flash-preview-tts)
+            temperature: Controls randomness in generation (0.0 to 1.0)
+            instructions: Optional instructions to guide the voice style (e.g., "Speak in a cheerful tone")
+            **kwargs: Additional parameters for future API options
+
+        Returns:
+            Dictionary with status and any additional information
+        """
+        try:
+            # Create content parts with instructions if provided
+            if instructions:
+                content_text = f"{instructions}: {text}"
+            else:
+                content_text = text
+
+            contents = [
+                genai_types.Content(
+                    role="user",
+                    parts=[
+                        genai_types.Part.from_text(text=content_text),
+                    ],
+                ),
+            ]
+
+            # Configure voice and response format
+            generate_content_config = genai_types.GenerateContentConfig(
+                temperature=temperature,
+                response_modalities=["audio"],
+                speech_config=genai_types.SpeechConfig(
+                    voice_config=genai_types.VoiceConfig(
+                        prebuilt_voice_config=genai_types.PrebuiltVoiceConfig(
+                            voice_name=voice
+                        )
+                    )
+                ),
+            )
+
+            # Process the streaming response
+            audio_chunks = []
+            for chunk in self.client.models.generate_content_stream(
+                model=model,
+                contents=contents,
+                config=generate_content_config,
+            ):
+                if (
+                    chunk.candidates is None
+                    or chunk.candidates[0].content is None
+                    or chunk.candidates[0].content.parts is None
+                ):
+                    continue
+
+                if inline_data := chunk.candidates[0].content.parts[0].inline_data:
+                    # Get the data and mime type
+                    data_buffer = inline_data.data
+                    mime_type = inline_data.mime_type
+
+                    # Convert to WAV if needed
+                    if not mime_type.startswith("audio/"):
+                        continue
+
+                    # Check if we need to convert the audio format
+                    file_extension = mimetypes.guess_extension(mime_type)
+                    if file_extension is None:
+                        file_extension = ".wav"
+                        data_buffer = self._convert_to_wav(data_buffer, mime_type)
+
+                    audio_chunks.append(data_buffer)
+
+            # Combine all audio chunks
+            audio_data = b"".join(audio_chunks)
+
+            # Save the audio data to output file
+            with open(output_path, "wb") as f:
+                f.write(audio_data)
+
+            # Verify the file was written correctly
+            if not Path(output_path).exists() or Path(output_path).stat().st_size == 0:
+                raise TTSError("Failed to write audio file")
+
+            result = {
+                "status": "success",
+                "model": model,
+                "voice": voice,
+            }
+
+            # Generate alignment if requested
+            if kwargs.get("return_alignment", False):
+                temp_path = Path(output_path)
+                temp_file = (
+                    temp_path.parent / f"{temp_path.stem}_temp{temp_path.suffix}"
+                )
+
+                try:
+                    with open(temp_file, "wb") as f:
+                        f.write(audio_data)
+                    asr_result = self.asr_manager.transcribe(
+                        "openai", temp_file, language=kwargs.get("language")
+                    )
+                    result["alignment"] = asr_result.to_elevenlabs_alignment()
+                finally:
+                    temp_file.unlink(missing_ok=True)
+
+            return result
+
+        except Exception as e:
+            # Handle rate limit errors specifically
+            if "rate limit" in str(e).lower() or "quota" in str(e).lower():
+                raise TTSRateLimitError(f"Gemini API rate limit exceeded: {str(e)}")
+            # Handle other errors
+            raise TTSError(f"Gemini TTS generation failed: {str(e)}")
+
+    def _convert_to_wav(self, audio_data: bytes, mime_type: str) -> bytes:
+        """Generates a WAV file header for the given audio data and parameters.
+
+        Args:
+            audio_data: The raw audio data as a bytes object.
+            mime_type: Mime type of the audio data.
+
+        Returns:
+            A bytes object representing the WAV file with header.
+        """
+        parameters = self._parse_audio_mime_type(mime_type)
+        bits_per_sample = parameters["bits_per_sample"]
+        sample_rate = parameters["rate"]
+        num_channels = 1
+        data_size = len(audio_data)
+        bytes_per_sample = bits_per_sample // 8
+        block_align = num_channels * bytes_per_sample
+        byte_rate = sample_rate * block_align
+        chunk_size = 36 + data_size  # 36 bytes for header fields before data chunk size
+
+        # Create WAV header
+        header = struct.pack(
+            "<4sI4s4sIHHIIHH4sI",
+            b"RIFF",  # ChunkID
+            chunk_size,  # ChunkSize (total file size - 8 bytes)
+            b"WAVE",  # Format
+            b"fmt ",  # Subchunk1ID
+            16,  # Subchunk1Size (16 for PCM)
+            1,  # AudioFormat (1 for PCM)
+            num_channels,  # NumChannels
+            sample_rate,  # SampleRate
+            byte_rate,  # ByteRate
+            block_align,  # BlockAlign
+            bits_per_sample,  # BitsPerSample
+            b"data",  # Subchunk2ID
+            data_size,  # Subchunk2Size (size of audio data)
+        )
+        return header + audio_data
+
+    def _parse_audio_mime_type(self, mime_type: str) -> dict[str, int]:
+        """Parses bits per sample and rate from an audio MIME type string.
+
+        Args:
+            mime_type: The audio MIME type string (e.g., "audio/L16;rate=24000").
+
+        Returns:
+            A dictionary with "bits_per_sample" and "rate" keys.
+        """
+        bits_per_sample = 16
+        rate = 24000
+
+        # Extract rate from parameters
+        parts = mime_type.split(";")
+        for param in parts:
+            param = param.strip()
+            if param.lower().startswith("rate="):
+                try:
+                    rate_str = param.split("=", 1)[1]
+                    rate = int(rate_str)
+                except (ValueError, IndexError):
+                    pass  # Keep rate as default
+            elif param.startswith("audio/L"):
+                try:
+                    bits_per_sample = int(param.split("L", 1)[1])
+                except (ValueError, IndexError):
+                    pass  # Keep bits_per_sample as default
+
+        return {"bits_per_sample": bits_per_sample, "rate": rate}
+
 
 class TTSManager:
     def __init__(self):
@@ -1282,6 +2023,8 @@ def create_tts_manager():
         manager.add_provider("minimaxi", MiniMaxiTTSProvider())
     if os.getenv("CARTESIA_API_KEY"):
         manager.add_provider("cartesia", CartesiaTTSProvider())
+    if os.getenv("GEMINI_API_KEY"):
+        manager.add_provider("gemini", GeminiTTSProvider())
     return manager
 
 
